@@ -1,20 +1,14 @@
-# Copyright (c) 2006-2007 gocept gmbh & co. kg
-# See also LICENSE.txt
-# $Id: filestore.py 30203 2009-10-08 13:09:31Z wosc $
 
+import gocept.filestore.interfaces
 import os
 import os.path
 import shutil
-
 import zope.interface
 
-import gocept.filestore.interfaces
-
 
+@zope.interface.implementer(gocept.filestore.interfaces.IFileStore)
 class FileStore(object):
 
-    zope.interface.implements(gocept.filestore.interfaces.IFileStore)
-
     sub_dirs = ('tmp', 'new', 'cur')
 
     def __init__(self, path):
@@ -27,13 +21,10 @@ class FileStore(object):
             dir = os.path.join(self.path, dir)
             if not os.path.exists(dir):
                 os.mkdir(dir)
-            if not os.path.isdir(dir):
-                raise RuntimeError("Could create directory %r, "
-                                   "something is in the way." % dir)
 
     def create(self, filename, mode='w'):
         path = os.path.join(self.path, 'tmp', filename)
-        f = file(path, mode)
+        f = open(path, mode)
         return f
 
     def copy(self, filename, source, destination):
@@ -55,4 +46,4 @@ class FileStore(object):
     def list(self, section):
         path = os.path.join(self.path, section)
         return [os.path.join(self.path, section, path)
-                for path in  os.listdir(path)]
+                for path in os.listdir(path)]
